ncscli is the command-line and python interface for Neocortix Cloud Services.

For an introduction, see [Neocortix Cloud Services](https://www.neocortix.com/cloud).

For Tutorials, examples and notes, see [Neocortix Tutorials](https://neocortix.com/tutorials)

For information about the command-line interface, see [COMMANDLINE.md](COMMANDLINE.md)
